# anchor: parts

|   |   |   |   |   |   |   |   |   |   |
| --- | --- | --- | --- | --- | --- | --- | --- | --- | --- |
| [`16 AWG wire`](../parts/16-awg-wire.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/16-awg-wire.jpeg?raw=true)](../parts/16-awg-wire.md) 40 cm x (red + black/blue) | [`433 MHz SMA whip antenna (small stubby or ~10–20 cm) or U.FL -> SMA pigtail if the module has a tiny U.FL connector.`](../parts/whip-antenna.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/whip-antenna.jpeg?raw=true)](../parts/whip-antenna.md)  | [`Raspberry Pi.`](../parts/rpi.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/rpi3bplus.png?raw=true)](../parts/rpi.md)  | [`SD card, 32 GB`](../parts/sd-card-32-gb.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/sd-card-32-gb.jpg?raw=true)](../parts/sd-card-32-gb.md)  | [`SX1276/77/78/79 UART`](../parts/sx1276.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/sx1276-1.jpg?raw=true)](../parts/sx1276.md)  | [`XL4015: 8 - 36 VDC -> 1.25 - 32 VDC, 5A`](../parts/XL4015.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/XL4015.png?raw=true)](../parts/XL4015.md)  | [`auto power connectors`](../parts/connector.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/connector.jpg?raw=true)](../parts/connector.md) 1 female | [`keyboard`](../parts/keyboard.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/keyboard.jpg?raw=true)](../parts/keyboard.md)  | [`nuts, bolts, and spacers`](../parts/nuts-bolts-spacers.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/nuts-bolts-spacers.jpg?raw=true)](../parts/nuts-bolts-spacers.md) M2.5: (4 x bolt + 4 x nut + 8 x 10 mm spacer) + M3: (1 x bolt + 5 x nut + 4 x 5 mm spacer + 4 x 15 mm spacer + 5 x 25 mm spacer) | [`on/off DC switch with indicator led`](../parts/dc-switch.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/on-off-switch.png?raw=true)](../parts/dc-switch.md)  |
| [`plexiglass, 2 mm or 2.5 mm thickness`](../parts/plexiglass.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/plexiglass.jpg?raw=true)](../parts/plexiglass.md) 14 cm x 9.5 cm | [`single-sided PCB, 14 cm x 9.5 cm`](../parts/PCB-single-14x9_5.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/pcb-14x9_5cm.jpg?raw=true)](../parts/PCB-single-14x9_5.md)  | [`solid cable 1-1.5 mm^2`](../parts/solid-cable-1-15.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/solid-cable-1-15.jpg?raw=true)](../parts/solid-cable-1-15.md) 10 cm x (red + black/blue) | [`the swallow shield`](../parts/swallow-shield.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/swallow-3d.png?raw=true)](../parts/swallow-shield.md)  |  |  |  |  |  |  |

1. [16 AWG wire](../parts/16-awg-wire.md): 40 cm x (red + black/blue).
1. [433 MHz SMA whip antenna (small stubby or ~10–20 cm) or U.FL -> SMA pigtail if the module has a tiny U.FL connector.](../parts/whip-antenna.md).
1. [Raspberry Pi.](../parts/rpi.md).
1. [SD card, 32 GB](../parts/sd-card-32-gb.md).
1. [SX1276/77/78/79 UART](../parts/sx1276.md).
1. [XL4015: 8 - 36 VDC -> 1.25 - 32 VDC, 5A](../parts/XL4015.md).
1. [auto power connectors](../parts/connector.md): 1 female.
1. [keyboard](../parts/keyboard.md).
1. [nuts, bolts, and spacers](../parts/nuts-bolts-spacers.md): M2.5: (4 x bolt + 4 x nut + 8 x 10 mm spacer) + M3: (1 x bolt + 5 x nut + 4 x 5 mm spacer + 4 x 15 mm spacer + 5 x 25 mm spacer).
1. [on/off DC switch with indicator led](../parts/dc-switch.md).
1. [plexiglass, 2 mm or 2.5 mm thickness](../parts/plexiglass.md): 14 cm x 9.5 cm.
1. [single-sided PCB, 14 cm x 9.5 cm](../parts/PCB-single-14x9_5.md).
1. [solid cable 1-1.5 mm^2](../parts/solid-cable-1-15.md): 10 cm x (red + black/blue).
1. [the swallow shield](../parts/swallow-shield.md).
